package Logoved::Stream::Out::Listener::SectionWriter;

use autodie qw/open close/;
use Moo;
has 'fh' => (
    is => 'lazy',
    predicate => 'has_fh',
    clearer => 'clear_fh',
);
# private; for debug messages
has '_fh_file' => (
    is => 'rw',
    );
with 'Logoved::Role::Stream::Out::Listener';

sub subscribe_stream {
    my ($class, $stream)=@_;
    my $sec_class=ref($stream);
    #return unless $sec_class =~ /Logoved::Stream::Out::Section::(?:beehive|hasher|rpmbuild)::/;
    return if not $stream->DOES('Logoved::Role::Stream::Out::Section');
    #return 1 if $sec_class eq 'Logoved::Stream::Out::Section::rpmbuild::files';
    return if $stream->DOES('Logoved::Stream::Out::Switch');
    return 1;
}

sub _get_section_path {
    my $self=shift;
    my $output_path=$self->listeners_factory->outdir;
    my $section_id=$self->stream->section_id;
    #warn "WRITER: $section_id\n";
    return $output_path.'/'.$section_id;
}

sub _build_fh {
    my $self=shift;
    my $section_path=$self->_get_section_path;
    open (my $fh, '>', $section_path);
    $self->_fh_file($section_path);
    return $fh;
}

sub write {
    my ($self, $line)=@_;
    my $fh=$self->fh;
    die "Oops! bad filehandle", $fh unless $fh;
    #print STDERR 'WRITER(L): ',$self->_fh_file, ': ', $line;
    print $fh $line or die 'Listener::Section::Writer: print to ',$self->_fh_file, ' failed: ',$!;
}

sub commit {
    my $self=shift;
    #print STDERR 'COMMIT(L): ',$self->_fh_file,"\n";
    close($self->fh()) if $self->has_fh;
    $self->clear_fh();
}

sub DEMOLISH {
    my $self=shift;
    if ($self->has_fh) {
	warn 'Section::Writer: internal: ',$self->_fh_file, ': not commited properly.';
	$self->commit();
    }
}

1;
