package Logoved::Stream::Out::Section::beehive::rpm::diff;
use Moo;
extends 'Logoved::Stream::Out::Section';
with 'Logoved::Role::Stream::Out::Section';

# may be Roled or Subclassed
has precount => (is => 'rw', default => 0);
has prebuffer => (is => 'rw', default => sub { [] } );

has _fileprefix => (is => 'rw');
has _expect_changeset_header => (is => 'rw', default => 0);
has _changeset_lines_minus => (is => 'rw', default => 0);
has _changeset_lines_plus => (is => 'rw', default => 0);
has _changeset_count_minus => (is => 'rw', default => 0);
has _changeset_count_plus => (is => 'rw', default => 0);

my $re0=qr!^--- (\S+)\.rpm\.repo\s!;
my $re1=qr/^\+\+\+ (\S+)\.rpm\.hasher\s/;
# @@ -21,3 +22,3 @@
my $re_changeset_header=qr/^\@\@\s-\d+(?:,(\d+))?\s\+\d+(?:,(\d+))?\s\@\@/;

#sub is_repeatable { return 1 };
sub is_unique { return 0 };

sub get_error_classes {
    use Logoved::Stream::Out::Section::hasher::timeout;
    return qw/
	Logoved::Stream::Out::Section::hasher::timeout
	/;
}

sub unshift_sections_on_reject {
    return qw/
	Logoved::Stream::Out::Section::beehive::rpm::missing
	Logoved::Stream::Out::Section::beehive::rpm::diff
	/;
}
#sub unshift_sections_on_reject {
#    return  __PACKAGE__ ;
#}

sub match_section_start {
    my ($self, $line) = @_;
    return $line =~ $re0;
};

sub accept {
    my ($self, $line) = @_;
    my $precount=$self->precount();
    # warn 'rpmdiff: c=',$precount,' H=',$self->_expect_changeset_header,
    # 	' ',$self->_changeset_lines_minus,',',$self->_changeset_lines_plus,
    # 	' -=',$self->_changeset_count_minus,' +=',$self->_changeset_count_plus,
    # 	' line=', $line;
    if (0==$precount) {
	if ($line=~ $re0) {
	    $self->_fileprefix($1);
	    return 1;
	} else {
	    $self->reject_prebuffer('line 0 does not match');
	    return 0;
	}
    } elsif (1==$precount) {
	if ($line=~ $re1) {
	    if ($1 eq $self->_fileprefix) {
		$self->_expect_changeset_header(1);
		return 1;
	    } else {
		$self->reject_prebuffer('line 1: rpm name does not match');
		return 0;
	    }
	} else {
	    $self->reject_prebuffer('line 1 does not match');
	    return 0;
	}
    } elsif ($precount>1) {
	if ($self->_expect_changeset_header) {
	    if ($line=~ $re_changeset_header) {
		my $lines_minus=$1;
		my $lines_plus=$2;
		# see https://en.wikipedia.org/wiki/Diff#Unified_format
		$lines_minus//=1;
		$lines_plus//=1;
		$self->_changeset_lines_minus($lines_minus);
		$self->_changeset_lines_plus($lines_plus);
		$self->_changeset_count_minus(0);
		$self->_changeset_count_plus(0);
		$self->_expect_changeset_header(0);
		return 1;
	    } else {
		# patch is ended; this line is no more a patch
		$self->commit_prebuffer();
		return 0;
	    }
	} else {
	    if ($line!~ m!^[-+ ]!) {
		$self->reject_prebuffer('expected patch changeset: '.$line);
	    # generally speaking, can be a valid part of a patch
	    #} elsif ($line=~ m!^--- !) {
	    #	$self->reject_prebuffer('Oops! expected changeset, got --- '.$line);
	    } else {
		$self->{_changeset_count_minus}+=1 if $line=~ m!^[- ]!;
		$self->{_changeset_count_plus}+=1 if $line=~ m!^[+ ]!;
		#use Data::Dumper; print Dumper($self);
		my $count_minus=$self->{_changeset_count_minus};
		my $count_plus=$self->{_changeset_count_plus};
		my $lines_minus=$self->{_changeset_lines_minus};
		my $lines_plus=$self->{_changeset_lines_plus};
		if ($count_minus>$lines_minus or $count_plus>$lines_plus) {
		    $self->reject_prebuffer('incorrect patch: line count does not match');
		    #warn 'DEBUG: reject_prebuffer: incorrect patch - line count does not match: +',$count_plus,'=',$lines_plus,'-',$count_minus,'=',$lines_minus);
		    return 0;
		} elsif ($count_minus==$lines_minus and $count_plus==$lines_plus) {
		    # correct patch - this section ended, expecting next
		    #warn "DEBUG: rpmdiff: changeset ended\n";
		    $self->_expect_changeset_header(1);
		    return 1
		} else {
		    # section is not ended yet
		    return 1
		}
	    }
	}
    }
}

sub write {
    my ($self, $line) = @_;
    $self->write_to_prebuffer($line);
    return 1;
}

sub commit {
    my ($self, $line) = @_;
    $self->commit_prebuffer($line);
    $self->commit_listeners($line);
    return 1;
}

sub write_to_prebuffer {
    my ($self, $line) = @_;
    $self->precount($self->precount+1);
    push @{$self->prebuffer}, $line;
}
sub reject_prebuffer {
    my ($self, $message) = @_;
    $self->precount(0);
    #warn 'DEBUG: ',$self->section_type, ': at ', $self->precount,': rejected: ',$message,"\n";
    $self->source->pushback_chunk($self->prebuffer);
    $self->prebuffer([]);
}

sub commit_prebuffer {
    my ($self) = @_;
    #warn 'DEBUG: ',$self->section_type,': flushed prebuffer',"\n";
    my $fileprefix=$self->_fileprefix;
    $self->messager->send_message('section_id', $fileprefix);
    # kill arch
    $fileprefix=~s/\.[^\.]+$//;
    # kill epoch
    $fileprefix=~s/-\d+:/-/;
    $self->messager->send_message('section_nvr', $fileprefix);
    # TODO write_chunk $self->prebuffer ?
    local $_;
    map {$self->write_listeners($_)} @{$self->prebuffer};
    $self->prebuffer([]);
}

1;
__END__
