package Logoved::Stream::Out::Section::rpmbuild::files::processing;
use Moo;
extends 'Logoved::Stream::Out::Section';
with 'Logoved::Role::Stream::Out::Section::rpmbuild';

sub is_mandatory {return 1};
sub is_unique { return 0 };

sub match_section_start {
    my ($self, $line) = @_;
    return $line=~/^Processing files: /;
};

sub accept {
    my ($self, $line) = @_;
    unless (
	$line=~/^Processing files: / or
	# libfakeroot: semop(-1): Invalid argument
	$line=~/^libfakeroot: semop\(-1\): Invalid argument/ or
	#rpm-build-guestfs-0.2-alt6:error: cannot write /usr/src/tmp/rpm-build-guestfs-buildroot/.post:rpm-build-guestfs
	$line=~m!^error: cannot write \S+-buildroot/\.! or
	#error: File must begin with "/": COPYING
	$line=~m!^error: File must begin with "/": ! or
	$line=~m!^error: Can't mix special \%doc with other forms: ! or
	$line=~m!^error: Symlink points to BuildRoot: ! or
	#$line=~m!^! or

	# moved to files::filelist_warnings
	#	$line=~/^warning: package with no files has \%\w+-script/ or
	#	$line=~/^warning: absolute symlink: / or

	# the warning is issued after find-requires and find-provides, so not in ::filelist_warnings
	#fvwm-2.6.8-alt1:warning: fvwm-full provides another subpackage: fvwm
	$line=~m!^warning: \S+ provides another subpackage: \S+! or
	# space separates error: messages and raised rpmbuild error
	$line=~m!^$!
) {
	warn 'DEBUG: rpmbuild::files::processing: unexpected: ', $line;
    }
    return 1;
}

1;
__END__
------------------------------------------------
Processing files: yaflight-0.99.29-alt1_7
error: File not found by glob: /usr/src/tmp/yaflight-buildroot/usr/share/icons/yaflight.*
------------------------------------------------
+ exit 0
Processing files: adcli-0.8.2-alt1.S1
Executing(%doc): /bin/sh -e /usr/src/tmp/rpm-tmp.81978
+ umask 022
+ /bin/mkdir -p /usr/src/RPM/BUILD
+ cd /usr/src/RPM/BUILD
+ cd adcli-0.8.2
+ DOCDIR=/usr/src/tmp/adcli-buildroot/usr/share/doc/adcli-0.8.2
+ export DOCDIR
+ rm -rf /usr/src/tmp/adcli-buildroot/usr/share/doc/adcli-0.8.2
+ /bin/mkdir -p /usr/src/tmp/adcli-buildroot/usr/share/doc/adcli-0.8.2
+ cp -prL AUTHORS COPYING ChangeLog NEWS README /usr/src/tmp/adcli-buildroot/usr/share/doc/adcli-0.8.2
+ chmod -R go-w /usr/src/tmp/adcli-buildroot/usr/share/doc/adcli-0.8.2
+ chmod -R a+rX /usr/src/tmp/adcli-buildroot/usr/share/doc/adcli-0.8.2
+ exit 0
Finding Provides (using /usr/lib/rpm/find-provides)
Executing: /bin/sh -e /usr/src/tmp/rpm-tmp.VhU5Wm
find-provides: running scripts (alternatives,debuginfo,lib,pam,perl,pkgconfig,python,shell)
Finding Requires (using /usr/lib/rpm/find-requires)
Executing: /bin/sh -e /usr/src/tmp/rpm-tmp.ktMlcf
find-requires: running scripts (cpp,debuginfo,files,lib,pam,perl,pkgconfig,pkgconfiglib,python,rpmlib,shebang,shell,static,symlinks)
Requires: /lib64/ld-linux-x86-64.so.2, libc.so.6(GLIBC_2.14)(64bit), libc.so.6(GLIBC_2.2.5)(64bit), libc.so.6(GLIBC_2.3)(64bit), libc.so.6(GLIBC_2.3.4)(64bit), libc.so.6(GLIBC_2.4)(64bit), libc.so.6(GLIBC_2.8)(64bit), libgssapi_krb5.so.2()(64bit) >= set:lkTRE, libgssapi_krb5.so.2(gssapi_krb5_2_MIT)(64bit), libk5crypto.so.3()(64bit) >= set:kicEHa03, libk5crypto.so.3(k5crypto_3_MIT)(64bit), libkrb5.so.3()(64bit) >= set:nhxcpLnMHvACAbRtggJ9jSJDMKak4lvUUiFj2oNt8rydayeDXF0cxgO7ADJHAqyYG736Z341mgFo5n6X0FvhfDVBF604Or0aLZcC2, libkrb5.so.3(krb5_3_MIT)(64bit), liblber-2.4.so.2()(64bit) >= set:lkuYn1, libldap-2.4.so.2()(64bit) >= set:mhB7hZlfghERcxAJ4t8wRmRdLvAZI0T81mKMSYrhNioeAZ9vqSZI42WbPIzE7n, libresolv.so.2()(64bit) >= set:khApQEp5LqjcPyP0, libresolv.so.2(GLIBC_2.2.5)(64bit), libresolv.so.2(GLIBC_2.9)(64bit), rtld(GNU_HASH)
Requires(rpmlib): rpmlib(SetVersions)
Finding debuginfo files (using /usr/lib/rpm/find-debuginfo-files)
Executing: /bin/sh -e /usr/src/tmp/rpm-tmp.d4RuGa
Creating adcli-debuginfo package
Processing files: adcli-debuginfo-0.8.2-alt1.S1
Finding Provides (using /usr/lib/rpm/find-provides)
Executing: /bin/sh -e /usr/src/tmp/rpm-tmp.goybq9
find-provides: running scripts (debuginfo)
Finding Requires (using /usr/lib/rpm/find-requires)
Executing: /bin/sh -e /usr/src/tmp/rpm-tmp.Bv7Rhb
find-requires: running scripts (debuginfo)
Requires: adcli = 0.8.2-alt1.S1, /usr/lib/debug/lib64/ld-linux-x86-64.so.2.debug, debug64(libc.so.6), debug64(libgssapi_krb5.so.2), debug64(libk5crypto.so.3), debug64(libkrb5.so.3), debug64(liblber-2.4.so.2), debug64(libldap-2.4.so.2), debug64(libresolv.so.2)
warning: Installed (but unpackaged) file(s) found:
__END__
Processing files: meteor-0.5.9-alt1
warning: absolute symlink: /usr/src/tmp/meteor-buildroot/usr/bin/meteor -> /usr/lib64/meteor/meteor
Finding Provides (using /usr/lib/rpm/find-provides)
Executing: /bin/sh -e /usr/src/tmp/rpm-tmp.CZwxmz
